from citrination_client.models.columns.base import BaseColumn

class OrganicChemicalFormulaColumn(BaseColumn):
    """
    An organic chemical formula column configuration for a data view.
    Parameterized with the basic column options.
    """

    TYPE = "Organic"
